<!doctype html>
<html lang="en">
    <head>
        <meta charset="utf-8">
        <meta http-equiv="x-ua-compatible" content="ie=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <title>My Hakyll Blog - $title$</title>
        <link rel="stylesheet" href="/css/default.css" />
    </head>
    <body>
        <header>
            <div class="logo">
                <a href="/">My Hakyll Blog</a>
            </div>
            <nav>
                <a href="/">Home</a>
                <a href="/about.html">About</a>
                <a href="/contact.html">Contact</a>
                <a href="/archive.html">Archive</a>
            </nav>
        </header>

        <main role="main">
            <h1>$title$</h1>
            $body$
        </main>

        <footer>
            Site proudly generated by
            <a href="http://jaspervdj.be/hakyll">Hakyll</a>
        </footer>
    </body>
</html>
